require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Artifact
      class ArtifactAttributes < UU::OS::REST::DTO

        # Code of the artifact.
        attr_accessor :code

        # URI of the company where artifact is located.
        # @deprecated
        attr_accessor :company_uri

        # URI of the competent role.
        attr_accessor :competent_role_uri

        # Creation stamp of the artifact.
        attr_accessor :creation_stamp

        # Creation time of the artifact.
        attr_accessor :creation_time

        # Description of the artifact.
        attr_accessor :description

        # URI of the artifact's icon.
        attr_accessor :icon_uri

        # Layout of the artifact.
        #
        # @deprecated Layouts are no longer used, this attribute has no effect.
        attr_accessor :layout

        # URI of the artifact container.
        attr_accessor :location_uri

        # URI of the meta artifact.
        attr_accessor :meta_artifact_uri

        # Modification stamp of the artifact.
        attr_accessor :modification_stamp

        # Modification time of the artifact.
        attr_accessor :modification_time

        # Name of the artifact.
        attr_accessor :name

        # URI of the organizational unit.
        attr_accessor :organizational_unit_uri

        # Version of the artifact.
        attr_accessor :version

        # Security level of the artifact.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # Comment of the current activity state.
        attr_accessor :state_comment

        # Name of the artifact state.
        attr_accessor :state_name

        # Type of the current artifact state.
        #
        # @see UU::OS::Artifact::ArtifactStateType
        attr_accessor :state_type

        # URI of the artifact.
        attr_accessor :uri

        # Flag of width sheet.
        #
        # @see UU::OS::Artifact::ArtifactWidthType
        attr_accessor :width

        # UESURI of the entity type of the artifact. Never nil.
        attr_accessor :entity_type_uri

        # Indicates whether the primarily displayed content of the Artifact is component content.
        attr_accessor :component_content

        # @deprecated Always returns nil.
        attr_accessor :artifact_type

        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end
        
        def code
          attributes[:code]
        end

        def  code=(val)
          attributes[:code] = val
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        # @deprecated Layouts are no longer used, this attribute has no effect.
        def layout
          attributes[:layout]
        end

        # @deprecated Layouts are no longer used, this attribute has no effect.
        def layout=(val)
          attributes[:layout] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end
        
        # @deprecated Use {ArtifactAttributes#version} instead.
        def revision 
          attributes[:version]
        end
        
        # @deprecated Use {ArtifactAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end
        
        def component_content
          attributes[:componentContent]
        end

        def component_content=(val) 
          attributes[:componentContent] = val
        end

      end 
    end
  end
end
