require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS

    module Cast
      class CastAccessRoleAttributes < UU::OS::REST::DTO

        # Name of the subject (personal access role or uuEE) which is casted to the subject_uri (role or group).
        attr_accessor :casted_subject_name

        # Code of the subject (personal access role or uuEE) which is casted to the subject_uri (role or group).
        attr_accessor :casted_subject_code

        # UESURI of the subject (personal access role or uuEE) which is casted to the subject_uri (role or group).
        attr_accessor :casted_subject_uri

        # Entity type URI of casted subject.
        attr_accessor :casted_subject_entity_type_uri

        # Access role cast level to the specified role. In case of the indirect cast, lowest value found
        # at access role cast path to the specified role is returned.
        #
        # @see UU::OS::Cast::CastLevel
        attr_accessor :level

        # Specifies if the cast is the primary cast to the role.
        attr_accessor :primary

        # Name of the subject (role or group) to which the casted_subject_uri is casted.
        attr_accessor :subject_name

        # Code of the subject (role or group) to which the casted_subject_uri is casted.
        attr_accessor :subject_code

        # UESURI of the subject (role or group) to which the casted_subject_uri is casted.
        attr_accessor :subject_uri

        # Entity type URI of subject.
        attr_accessor :subject_entity_type_uri

        def casted_subject_name
          attributes[:castedSubjectName]
        end

        def casted_subject_name=(val)
          attributes[:castedSubjectName] = val
        end

        def casted_subject_code
          attributes[:castedSubjectCode]
        end

        def casted_subject_code=(val)
          attributes[:castedSubjectCode] = val
        end

        def casted_subject_uri
          attributes[:castedSubjectUri]
        end

        def casted_subject_uri=(val)
          if val
            attributes[:castedSubjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectUri] = nil
          end
        end

        def casted_subject_entity_type_uri
          attributes[:castedSubjectEntityTypeUri]
        end

        def casted_subject_entity_type_uri=(val)
          if val
            attributes[:castedSubjectEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castedSubjectEntityTypeUri] = nil
          end
        end

        def level
          attributes[:level]
        end

        def level=(val)
          attributes[:level] = val
        end

        def primary
          attributes[:primary]
        end

        def primary=(val)
          attributes[:primary] = val
        end

        def subject_name
          attributes[:subjectName]
        end

        def subject_name=(val)
          attributes[:subjectName] = val
        end

        def subject_code
          attributes[:subjectCode]
        end

        def subject_code=(val)
          attributes[:subjectCode] = val
        end

        def subject_uri
          attributes[:subjectUri]
        end

        def subject_uri=(val)
          if val
            attributes[:subjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:subjectUri] = nil
          end
        end

        def subject_entity_type_uri
          attributes[:subjectEntityTypeUri]
        end

        def subject_entity_type_uri=(val)
          if val
            attributes[:subjectEntityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:subjectEntityTypeUri] = nil
          end
        end

      end
    end

  end

end
