require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module MetaArtifact
      # Attributes of the meta artifact template presentation setting.
      class MetaArtifactDefaultPresentationAttributes < UU::OS::REST::DTO
        # Normalized UESURI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # Width of the artifact. Never nil. Possible values see in {UU::OS::Artifact::ArtifactWidthType}.
        attr_accessor :artifact_width

        # Header type. Never nil. Possible values see in {UU::OS::Artifact::ArtifactHeaderDisplayMode}.
        attr_accessor :header_display_mode

        # Show/hide control bar. Never nil. Possible values see in {UU::OS::Artifact::ArtifactControlBarDisplayMode}.
        attr_accessor :control_bar_display_mode

        # Show/hide comments. Never nil. Possible values see in {UU::OS::Artifact::ArtifactCommentsDisplayMode}.
        attr_accessor :comment_display_mode

        # @deprecated Use {#artifact_display_mode} instead.
        attr_accessor :context_menu_display_mode

        # Show simple or advanced context menu. Never nil. Possible values see in {UU::OS::Artifact::ArtifactDisplayMode}.
        attr_accessor :artifact_display_mode

        # @deprecated Use {#lock_personal_settings} and {#lock_artifact_settings} instead.
        attr_accessor :lock_settings
        
        # This option forbids any change of artifact presentation through user settings. The artifacts created from this meta artifact will be displayed based on the meta artifact's presentation template (or based on artifact presentation settings if they're not locked) regardless of the general user settings.
        attr_accessor :lock_personal_settings
        
        # This option forbids the modification of artifact presentation settings on artifacts created from this meta artifact. The artifacts will be displayed based on the meta artifact's presentation template and general user settings regardless of the artifact presentation settings.
        attr_accessor :lock_artifact_settings

        # Represents visual style. Possible values see in {UU::OS::Artifact::ArtifactVisualStyle}.
        attr_accessor :visual_style

        # Show/hide navigation area when displaying sheet content.
        # Navigation area contains navigation bar, header, heading and control bar. Possible values see in {UU::OS::Artifact::ArtifactNavigationAreaDisplayMode}.
        attr_accessor :navigation_area_display_mode
        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def artifact_width
          attributes[:artifactWidth]
        end

        def  artifact_width=(val)
          attributes[:artifactWidth] = val
        end

        def header_display_mode
          attributes[:headerDisplayMode]
        end

        def header_display_mode=(val)
          attributes[:headerDisplayMode] = val
        end

        def control_bar_display_mode
          attributes[:controlBarDisplayMode]
        end

        def control_bar_display_mode=(val)
          attributes[:controlBarDisplayMode] = val
        end

        def comment_display_mode
          attributes[:commentDisplayMode]
        end

        def comment_display_mode=(val)
          attributes[:commentDisplayMode] = val
        end

        # @deprecated
        def context_menu_display_mode
          attributes[:contextMenuDisplayMode]
        end

        # @deprecated
        def context_menu_display_mode=(val)
          attributes[:contextMenuDisplayMode] = val
        end

        def artifact_display_mode
          attributes[:artifactDisplayMode]
        end

        def artifact_display_mode=(val)
          attributes[:artifactDisplayMode] = val
        end

        def lock_settings
          attributes[:lockSettings]
        end

        def lock_settings=(val)
          attributes[:lockSettings] = val
        end
        
        def lock_personal_settings
          attributes[:lockPersonalSettings]
        end

        def lock_personal_settings=(val)
          attributes[:lockPersonalSettings] = val
        end
        
        def lock_artifact_settings
          attributes[:lockArtifactSettings]
        end

        def lock_artifact_settings=(val)
          attributes[:lockArtifactSettings] = val
        end

        def visual_style
          attributes[:visualStyle]
        end

        def visual_style=(val)
          attributes[:visualStyle] = val
        end

        def navigation_area_display_mode
          attributes[:navigationAreaDisplayMode]
        end

        def navigation_area_display_mode=(val)
          attributes[:navigationAreaDisplayMode] = val
        end

      end
    end
  end
end
