require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
      module Property

        class PropertyAttributes < UU::OS::REST::DTO

          # Normalized UESURI of the property.
          attr_accessor :uri

          # Name of the property.
          attr_accessor :name

          # Code of the property.
          attr_accessor :code

          # Description of the property.
          attr_accessor :description

          # Normalized UESURI of the property template.
          attr_accessor :template_uri

          # Type of property.
          attr_accessor :type

          # Normalized UESURI of the parent collection. If the property is in the root collection, nil is returned.
          attr_accessor :collection_uri

          # UESURI of the entity type of the property
          attr_accessor :entity_type_uri

          # Value of property (if property type is binary data, then value is nil).
          attr_accessor :value
          
          # Creation time of the property.
          attr_accessor :creation_time
          
          # Modification time of the property.
          attr_accessor :modification_time

          # Version of the property.
          attr_accessor :version

          def uri
            attributes[:uri]
          end

          def uri=(val) 
            if val
              attributes[:uri] = UU::OS::UESURI.new(val)
            else
              attributes[:uri] = nil
            end
          end

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def template_uri 
            attributes[:templateUri]
          end

          def template_uri=(val) 
            if val
              attributes[:templateUri] = UU::OS::UESURI.new(val)
            else
              attributes[:templateUri] = nil
            end
          end

          def type 
            attributes[:type]
          end

          def type=(val) 
            attributes[:type] = val
          end

          def collection_uri 
            attributes[:collectionUri]
          end

          def collection_uri=(val) 
            if val
              attributes[:collectionUri] = UU::OS::UESURI.new(val)
            else
              attributes[:collectionUri] = nil
            end
          end

          def entity_type_uri 
            attributes[:entityTypeUri]
          end

          def entity_type_uri=(val) 
            if val
              attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
            else
              attributes[:entityTypeUri] = nil
            end
          end

          def value 
            attributes[:value]
          end

          def value=(val) 
            # Value is not transformed, because it is Object. Only chance to guess
            # proper value type is either from type or template_uri attributes. But
            # these attributes are not available on plain get_value command.
            # Therefore we are not transforming data here to maintain API consistency.
            # Caller has to know which type he expects and parse value manually.
            attributes[:value] = val
          end
          
          def creation_time 
            attributes[:creation_time]
          end

          def creation_time=(val) 
            attributes[:creation_time] = val
          end
          
          def modification_time 
            attributes[:modification_time]
          end

          def modification_time=(val) 
            attributes[:modification_time] = val
          end

          def version
            attributes[:version]
          end

          def version=(val)
            attributes[:version] = val
          end

        end

      end
    end
end
